@@ -6,7 +6,7 @@ use Lyrics::Fetcher::Cache;
 
 # Lyrics Fetcher
 #
-# Copyright (C) 2007-08 David Precious <davidp@preshweb.co.uk> (CPAN: BIGPRESH)
+# Copyright (C) 2007-10 David Precious <davidp@preshweb.co.uk> (CPAN: BIGPRESH)
 #
 # Originally authored by and copyright (C) 2003 Sir Reflog <reflog@gmail.com>
 # who kindly passed maintainership on to David Precious in Feb 2007
@@ -29,11 +29,11 @@ use Lyrics::Fetcher::Cache;
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-# $Id: Fetcher.pm 270 2008-02-29 10:58:38Z davidp $
+# $Id$
 
 use vars qw($VERSION $Error @FETCHERS $Fetcher $debug);
 
-$VERSION = '0.5.1';
+$VERSION = '0.5.2';
 $Error   = 'OK';      #return status string
 
 $debug = 0; # If you want debug messages, set debug to a true value, and
@@ -79,6 +79,9 @@ Lyrics::Fetcher - Perl extension to manage fetchers of song lyrics.
       # or you can pass an arrayref of fetchers you want used:
       print Lyrics::Fetcher->fetch('Oasis', 'Whatever', [qw(LyricWiki Google)]);
 
+      # To find out which fetchers are available:
+      my @fetchers = Lyrics::Fetcher->available_fetchers;
+
 
 =head1 DESCRIPTION
 
@@ -94,7 +97,7 @@ result.
 In case of module error the Fetchers must return undef with the error 
 description in $@.
 
-In case of problems with lyrics' fetching, the error fill be returned in the 
+In case of problems with lyrics' fetching, the error will be returned in the 
 $Lyrics::Fetcher::Error string.  If all goes well, it will have 'OK' in it.
 
 The fetcher selection is made by the "method" parameter passed to the fetch() 
@@ -113,6 +116,9 @@ fetcher package name.
 
 Returns a list of available fetcher modules.
 
+  say "Fetchers available: " . join ',', Lyrics::Fetcher->available_fetchers;
+
+
 =cut
 
 sub available_fetchers {
@@ -129,6 +135,13 @@ containing the name of the fetcher you want to use, or an arrayref of fetchers
 you want to try (in the order you want them tried).  By default, each fetcher
 module which is installed will be tried.
 
+  if (my $lyrics = Lyrics::Fetcher->fetch('Oasis', 'Whatever')) {
+      say $lyrics;
+  } else {
+      warn "Failed to fetch lyrics - error was: " . $Lyrics::Fetcher::ERROR;
+  }
+
+
 =cut
 
 sub fetch {
@@ -272,18 +285,16 @@ fetcher.  Or, feel free to code it up yourself and send it to me (or upload
 it to CPAN yourself) if you want to be really helpful ;)
 
 
-=head1 BUGS
-
-There are no known bugs, if you catch one please let me know.
-
-
 =head1 CONTACT AND COPYRIGHT
 
-Copyright 2007-2008 David Precious <davidp@preshweb.co.uk> (CPAN Id: BIGPRESH)
+Copyright 2007-2010 David Precious <davidp@preshweb.co.uk> (CPAN Id: BIGPRESH)
 
 All comments / suggestions / bug reports gratefully received (ideally use the
 RT installation at http://rt.cpan.org/ but mail me direct if you prefer)
 
+Developed on Github at http://github.com/bigpresh/Lyrics-Fetcher
+
+
 Previously:
 Copyright 2003 Sir Reflog <reflog@mail15.com>. 
 Copyright 2003 Zachary P. Landau <kapheine@hypa.net>
